@@ -1,3 +1,4 @@
+#-*- coding: utf-8 -*-
 # classicmenu-indicator - an indicator showing the main menu from Gnome Classic
 #
 # Copyright (C) 2011 Florian Diesch <devel@florian-diesch.de>
@@ -18,11 +19,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from cmindicator import main
+from classicmenu_indicator.cmindicator import main
+
 
 
-if __name__ == '__main__':
-    try:
-      main()
-    except KeyboardInterrupt:
-      pass
